diy-django
==========

   .. image:: http://img.shields.io/travis/collinanderson/diy-django.svg
   .. image:: http://img.shields.io/pypi/v/diy-django.svg
   .. image:: http://img.shields.io/pypi/l/diy-django.svg


http://diy-django.readthedocs.org
